/**
 * jQuery acms-bitlyshorten plugin 1.0 (2011-06-22)
 *
 * Copyright (c) 2011 appleple.com
 *
 * @example
 *
 * ■ カスタムデータ属性（data-*）として，data-shorten属性に短縮したいURLを指定します．
 *   短縮URLの取得に失敗した場合は，その要素についての処理は無視されます．
 *
 * ■ HEAD要素等で，以下のようなコードで初期化してください（このファイルは任意の場所でパスを通して下さい）
 *   bit.lyのAPI Keyが必要です．取得済みであれば "https://bitly.com/a/your_api_key" で確認できます．
 *     <script type="text/javascript" src="/js/jquery.acms-bitlyshorten.js"></script>
 *     <script type="text/javascript">
 *     jQuery(function() {
 *         $('[data-shorten]').acmsBitlyShorten({
 *             login   : 'bitly Username',
 *             apiKey  : 'bitly API Key'
 *         });
 *     });
 *     </script>
 *
 * ■ INPUT要素の場合
 *     <input type="text" name="sample" value="{url}" data-shorten="{url}" />
 *
 *     data-shortenで指定されたURLが，value属性に含まれていれば，bit.lyの短縮URLに置き換わります．
 *     TEXTAREA要素，OPTION要素も同様にvalue属性を書き換えます．
 *
 * ■ P要素および内包されるA要素の場合
 *   <p data-shorten="%{BLOG_URL}"><a href="%{BLOG_URL}">リンク先 ( %{BLOG_URL} )</a></p>
 *
 *   data-shortenで指定されたURLが，要素内のHTMLに含まれていれば，bit.lyの短縮URLに置き換わります．
 *   HTMLを探索するため，子要素のA要素のhref属性なども書き換えが行われます．
 */

(function($) {
$.fn.acmsBitlyShorten = function(options) {
    var defaults = {
            login : '',
            apiKey: '',
            needle: 'shorten'
        },
        settings = $.extend({}, defaults, options);

    this.each(function() {
        var $self = $(this),
            url = $self.data(settings.needle);

        $.ajax({
            url : 'http://api.bitly.com/v3/shorten',
            type: 'GET',
            data: {
                login  : settings.login,
                apiKey : settings.apiKey,
                longUrl: encodeURI(url)
            },
            dataType: 'json',
            success: function(res) {
                var regex = new RegExp(url, 'g');

                if ( !res.data.url ) {
                    return;
                }
                if ( '|INPUT|TEXTAREA|OPTION|'.indexOf('|'+$self.get(0).tagName+'|') !== -1 ) {
                    $self.val($self.val().replace(regex, res.data.url));
                } else {
                    $self.html($self.html().replace(regex, res.data.url));
                }
            }
        })
    });
};
})(jQuery);